==> App-git_log_ch_usrdata-0.01.tar.gz: App-git_log_ch_usrdata-0.01/README.md <==
# NAME

App::git\_log\_ch\_usrdata - Change username and email address in git log

# VERSION

Version 0.01

# DESCRIPTION

The username and email address in the Git log can be changed with
[git\_log\_ch\_usrdata](https://metacpan.org/pod/git_log_ch_usrdata). For more information, see the documentation for this
script.

# AUTHOR

Klaus Rindfrey, `<klausrin at cpan.org.eu>`

# BUGS

Please report any bugs or feature requests to `bug-app-git_log_ch_usrdata at rt.cpan.org`, or through
the web interface at [https://rt.cpan.org/NoAuth/ReportBug.html?Queue=App-git\_log\_ch\_usrdata](https://rt.cpan.org/NoAuth/ReportBug.html?Queue=App-git_log_ch_usrdata).  I will be notified, and then you'll
automatically be notified of progress on your bug as I make changes.

# SEE ALSO

[APP::ghmulti](https://metacpan.org/pod/APP%3A%3Aghmulti), [git\_log\_ch\_usrdata](https://metacpan.org/pod/git_log_ch_usrdata)

# SUPPORT

You can find documentation for this module with the perldoc command.

    perldoc App::git_log_ch_usrdata

You can also look for information at:

- RT: CPAN's request tracker (report bugs here)

    [https://rt.cpan.org/NoAuth/Bugs.html?Dist=App-git\_log\_ch\_usrdata](https://rt.cpan.org/NoAuth/Bugs.html?Dist=App-git_log_ch_usrdata)

- Search CPAN

    [https://metacpan.org/release/App-git\_log\_ch\_usrdata](https://metacpan.org/release/App-git_log_ch_usrdata)

- GitHub Repository

    [https://github.com/klaus-rindfrey/perl-app-git\_log\_ch\_usrdata](https://github.com/klaus-rindfrey/perl-app-git_log_ch_usrdata)

# LICENSE AND COPYRIGHT

This software is copyright (c) 2025 by Klaus Rindfrey.

This is free software; you can redistribute it and/or modify it under
the same terms as the Perl 5 programming language system itself.

==> App-git_log_ch_usrdata-0.02.tar.gz: App-git_log_ch_usrdata-0.02/README.md <==
# NAME

App::git\_log\_ch\_usrdata - Change username and email address in git log

# VERSION

Version 0.01

# DESCRIPTION

The username and email address in the Git log can be changed with
[git\_log\_ch\_usrdata](https://metacpan.org/pod/git_log_ch_usrdata). For more information, see the documentation for this
script.

# AUTHOR

Klaus Rindfrey, `<klausrin at cpan.org.eu>`

# BUGS

Please report any bugs or feature requests to `bug-app-git_log_ch_usrdata at rt.cpan.org`, or through
the web interface at [https://rt.cpan.org/NoAuth/ReportBug.html?Queue=App-git\_log\_ch\_usrdata](https://rt.cpan.org/NoAuth/ReportBug.html?Queue=App-git_log_ch_usrdata).  I will be notified, and then you'll
automatically be notified of progress on your bug as I make changes.

# SEE ALSO

[App::ghmulti](https://metacpan.org/pod/App%3A%3Aghmulti), [git\_log\_ch\_usrdata](https://metacpan.org/pod/git_log_ch_usrdata)

# SUPPORT

You can find documentation for this module with the perldoc command.

    perldoc App::git_log_ch_usrdata

You can also look for information at:

- RT: CPAN's request tracker (report bugs here)

    [https://rt.cpan.org/NoAuth/Bugs.html?Dist=App-git\_log\_ch\_usrdata](https://rt.cpan.org/NoAuth/Bugs.html?Dist=App-git_log_ch_usrdata)

- Search CPAN

    [https://metacpan.org/release/App-git\_log\_ch\_usrdata](https://metacpan.org/release/App-git_log_ch_usrdata)

- GitHub Repository

    [https://github.com/klaus-rindfrey/perl-app-git\_log\_ch\_usrdata](https://github.com/klaus-rindfrey/perl-app-git_log_ch_usrdata)

# LICENSE AND COPYRIGHT

This software is copyright (c) 2025 by Klaus Rindfrey.

This is free software; you can redistribute it and/or modify it under
the same terms as the Perl 5 programming language system itself.
